@@ -322,9 +322,9 @@ class Cache(AbstractService):
                 self.remove(hash_for_remove, cause, remove_all=False)
                 self.put(message)
 
-        def check_no_match_within_timeout(self, actual_timestamp: int, timeout: int, clean_timeout: Optional[int]):
-            if clean_timeout is not None:
-                self.clear_out_of_timeout(actual_timestamp, clean_timeout)
+        def check_no_match_within_timeout(self, actual_timestamp: int, timeout: int, clean_timestamp: Optional[int]):
+            if clean_timestamp is not None:
+                self.clear_out_of_timeout(clean_timestamp)
             lower_bound_timestamp = actual_timestamp - timeout
             for timestamp, hashes in self.hash_by_sorted_timestamp.items():
                 if timestamp < lower_bound_timestamp:
@@ -372,10 +372,15 @@ class Cache(AbstractService):
                 while hash_for_remove in self.data and len(self.data[hash_for_remove]) != 0:
                     self.remove(hash_for_remove, cause, remove_all=False)
 
-        def clear_out_of_timeout(self, actual_timestamp, clean_timeout):
+        def wipe(self):
+            self.data.clear()
+            self.hash_by_sorted_timestamp.clear()
+            self.size = 0
+
+        def clear_out_of_timeout(self, clean_timestamp):
             hashes_to_removal = list()
             for timestamp, hashes in self.hash_by_sorted_timestamp.items():
-                if timestamp < actual_timestamp - clean_timeout:
+                if timestamp < clean_timestamp:
                     hashes_to_removal.append(hashes)
                 else:
                     break
